@@ -1,6 +1,6 @@
 /*
  * oath.h - header file for liboath
- * Copyright (C) 2009-2013 Simon Josefsson
+ * Copyright (C) 2009-2014 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -51,7 +51,7 @@ extern "C"
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "2.4.1"
+#define OATH_VERSION "2.6.0"
 
 /**
  * OATH_VERSION_NUMBER
@@ -226,6 +226,20 @@ oath_hotp_validate_callback (const char *secret,
 #define OATH_TOTP_DEFAULT_TIME_STEP_SIZE	30
 #define OATH_TOTP_DEFAULT_START_TIME		((time_t) 0)
 
+/**
+ * oath_totp_flags:
+ * @OATH_TOTP_HMAC_SHA256: Use HMAC-SHA256 instead of HMAC-SHA1.
+ * @OATH_TOTP_HMAC_SHA512: Use HMAC-SHA512 instead of HMAC-SHA1.
+ *
+ * Flags for oath_totp_generate2().
+ *
+ * Since: 2.6.0
+ */
+typedef enum {
+  OATH_TOTP_HMAC_SHA256 = 1,
+  OATH_TOTP_HMAC_SHA512 = 2
+} oath_totp_flags;
+
 extern OATHAPI int
 oath_totp_generate (const char *secret,
 		    size_t secret_length,
@@ -234,6 +248,16 @@ oath_totp_generate (const char *secret,
 		    time_t start_offset,
 		    unsigned digits, char *output_otp);
 
+extern OATHAPI int
+oath_totp_generate2 (const char *secret,
+		     size_t secret_length,
+		     time_t now,
+		     unsigned time_step_size,
+		     time_t start_offset,
+		     unsigned digits,
+		     int flags,
+		     char *output_otp);
+
 extern OATHAPI int
 oath_totp_validate (const char *secret,
 		    size_t secret_length,
@@ -299,6 +323,32 @@ oath_totp_validate3_callback (const char *secret,
 			      oath_validate_strcmp_function strcmp_otp,
 			      void *strcmp_handle);
 
+extern OATHAPI int
+oath_totp_validate4 (const char *secret,
+		     size_t secret_length,
+		     time_t now,
+		     unsigned time_step_size,
+		     time_t start_offset,
+		     size_t window,
+		     int *otp_pos,
+		     uint64_t *otp_counter,
+		     int flags,
+		     const char *otp);
+
+extern OATHAPI int
+oath_totp_validate4_callback (const char *secret,
+			      size_t secret_length,
+			      time_t now,
+			      unsigned time_step_size,
+			      time_t start_offset,
+			      unsigned digits,
+			      size_t window,
+			      int *otp_pos,
+			      uint64_t *otp_counter,
+			      int flags,
+			      oath_validate_strcmp_function strcmp_otp,
+			      void *strcmp_handle);
+
 /* Usersfile */
 
 extern OATHAPI int
